==> adfurikun-1.2.0.tar.gz: example/lib/nativead_sample.dart <==
import 'dart:io';

import 'package:adfurikun/nativead.dart';
import 'package:adfurikun_example/constants.dart';
import 'package:flutter/material.dart';
import 'package:fluttertoast/fluttertoast.dart';

class NativeAdPage extends StatefulWidget {
  NativeAdPage({Key? key}) : super(key: key);
  @override
  NativeAdPageState createState() => NativeAdPageState();
}

class NativeAdPageState extends State<NativeAdPage> with WidgetsBindingObserver {

  late AdfurikunNativeAd nativeAd;

  double width = 320;
  double height = 180;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text("NativeAd Sample"),
      ),
      body: Center(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.start,
          children: <Widget>[
            FractionallySizedBox(
                widthFactor: 0.9,
                child: ElevatedButton(
                    onPressed: () => load(),
                    child: Text("Load")
                )
            ),
            FractionallySizedBox(
                widthFactor: 0.9,
                child: ElevatedButton(
                    onPressed: () => show(),
                    child: Text("Show")
                )
            ),
            Container(
                width: width,
                height: height,
                child: nativeAd.adWidget()
            )
          ],
        ),
      ),
    );
  }

  @override
  void initState() {
    super.initState();
    WidgetsBinding.instance?.addObserver(this);
    String appId = "";
    if (Platform.isAndroid) {
      appId = ANDROID_NATIVE_AD_APPID;
    } else {
      appId = IOS_NATIVE_AD_APPID;
    }
    nativeAd = AdfurikunNativeAd(appId, width, height);
    nativeAd.listener = notifyCallback;
  }

  @override
  void dispose() {
    super.dispose();
    WidgetsBinding.instance?.removeObserver(this);
    nativeAd.destroy();
    nativeAd.listener = null;
  }

  @override
  void didChangeAppLifecycleState(AppLifecycleState state) {
    super.didChangeAppLifecycleState(state);
    if (AppLifecycleState.resumed == state) {
      nativeAd.resume();
    } else if (AppLifecycleState.paused == state) {
      nativeAd.pause();
    }
  }

  void load() {
    nativeAd.load();
  }

  void show() {
    nativeAd.play();
  }

  void notifyCallback(AdfurikunNativeAdCallback? callback, String? appId, String? adNetworkKey,
      String? title, String? description, int? errorCode) {
    if (AdfurikunNativeAdCallback.onNativeAdLoadFinish == callback) {
      Fluttertoast.showToast(msg: "読み込み成功");
    } else if (AdfurikunNativeAdCallback.onNativeAdLoadError == callback) {
      Fluttertoast.showToast(msg: "読み込み失敗");
    } else if (AdfurikunNativeAdCallback.onNativeAdViewPlayStart == callback) {
      Fluttertoast.showToast(msg: "再生開始");
    } else if (AdfurikunNativeAdCallback.onNativeAdViewPlayFinish == callback) {
      Fluttertoast.showToast(msg: "再生終了");
    } else if (AdfurikunNativeAdCallback.onNativeAdViewPlayFail == callback) {
      Fluttertoast.showToast(msg: "再生失敗");
    } else if (AdfurikunNativeAdCallback.onNativeAdViewClicked == callback) {
      Fluttertoast.showToast(msg: "広告クリック");
    }
  }
}

==> adfurikun-1.5.0.tar.gz: example/lib/nativead_sample.dart <==
import 'dart:io';

import 'package:adfurikun/nativead.dart';
import 'package:adfurikun_example/constants.dart';
import 'package:flutter/material.dart';
import 'package:fluttertoast/fluttertoast.dart';

class NativeAdPage extends StatefulWidget {
  NativeAdPage({Key? key}) : super(key: key);
  @override
  NativeAdPageState createState() => NativeAdPageState();
}

class NativeAdPageState extends State<NativeAdPage> {

  late AdfurikunNativeAd nativeAd;

  double width = 320;
  double height = 180;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text("NativeAd Sample"),
      ),
      body: Center(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.start,
          children: <Widget>[
            FractionallySizedBox(
                widthFactor: 0.9,
                child: ElevatedButton(
                    onPressed: () => load(),
                    child: Text("Load")
                )
            ),
            FractionallySizedBox(
                widthFactor: 0.9,
                child: ElevatedButton(
                    onPressed: () => show(),
                    child: Text("Show")
                )
            ),
            Container(
                width: width,
                height: height,
                child: nativeAd.adWidget()
            )
          ],
        ),
      ),
    );
  }

  @override
  void initState() {
    super.initState();
    String appId = "";
    if (Platform.isAndroid) {
      appId = ANDROID_NATIVE_AD_APPID;
    } else {
      appId = IOS_NATIVE_AD_APPID;
    }
    nativeAd = AdfurikunNativeAd(appId, width, height);
    nativeAd.listener = notifyCallback;
  }

  @override
  void dispose() {
    super.dispose();
    nativeAd.destroy();
    nativeAd.listener = null;
  }

  void load() {
    nativeAd.load();
  }

  void show() {
    nativeAd.play();
  }

  void notifyCallback(AdfurikunNativeAdCallback? callback, String? appId, String? adNetworkKey,
      String? title, String? description, int? errorCode) {
    if (AdfurikunNativeAdCallback.onNativeAdLoadFinish == callback) {
      Fluttertoast.showToast(msg: "読み込み成功");
    } else if (AdfurikunNativeAdCallback.onNativeAdLoadError == callback) {
      Fluttertoast.showToast(msg: "読み込み失敗");
    } else if (AdfurikunNativeAdCallback.onNativeAdViewPlayStart == callback) {
      Fluttertoast.showToast(msg: "再生開始");
    } else if (AdfurikunNativeAdCallback.onNativeAdViewPlayFinish == callback) {
      Fluttertoast.showToast(msg: "再生終了");
    } else if (AdfurikunNativeAdCallback.onNativeAdViewPlayFail == callback) {
      Fluttertoast.showToast(msg: "再生失敗");
    } else if (AdfurikunNativeAdCallback.onNativeAdViewClicked == callback) {
      Fluttertoast.showToast(msg: "広告クリック");
    }
  }
}
